Module gluon_vm::gc
[−]
[src]
Structs
| Gc |
A mark and sweep garbage collector. |
| GcPtr |
A pointer to a garbage collected value. |
| Generation | |
| Move |
|
| WriteOnly |
Pointer type which can only be written to. |
Traits
| CollectScope | |
| DataDef |
A definition of some data which may be allocated by the garbage collector. |
| FromPtr |
Trait which creates a typed pointer from a *mut () pointer.
For |
| Traverseable |
Trait which must be implemented on all root types which contain |